part of forestvpn_auth_api.api;



class AuthApi {
  final ApiClient apiClient;

  AuthApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Token introspection with HTTP info returned
  ///
  /// The introspection endpoint allows to check if a token (both refresh and access) is active or not.
  Future<Response> introspectWithHttpInfo(IntrospectionRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/introspect/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Token introspection
  ///
  /// The introspection endpoint allows to check if a token (both refresh and access) is active or not.
  Future<IntrospectionResponse> introspect(IntrospectionRequest request) async {
    Response response = await introspectWithHttpInfo(request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'IntrospectionResponse') as IntrospectionResponse;
    } else {
      return null;
    }
  }

  /// Login with HTTP info returned
  ///
  /// 
  Future<Response> loginWithHttpInfo(UserLoginRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/login/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Login
  ///
  /// 
  Future<TokenResponse> login(UserLoginRequest request) async {
    Response response = await loginWithHttpInfo(request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'TokenResponse') as TokenResponse;
    } else {
      return null;
    }
  }

  /// Get authenticated user&#39;s profile with HTTP info returned
  ///
  /// 
  Future<Response> profileGetWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/profile/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get authenticated user&#39;s profile
  ///
  /// 
  Future<UserProfile> profileGet() async {
    Response response = await profileGetWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'UserProfile') as UserProfile;
    } else {
      return null;
    }
  }

  /// Refresh access token with HTTP info returned
  ///
  /// 
  Future<Response> refreshTokenWithHttpInfo(TokenRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/token/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Refresh access token
  ///
  /// 
  Future<TokenResponse> refreshToken(TokenRequest request) async {
    Response response = await refreshTokenWithHttpInfo(request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'TokenResponse') as TokenResponse;
    } else {
      return null;
    }
  }

  /// Create user registration session with HTTP info returned
  ///
  /// 
  Future<Response> registrationSessionCreateWithHttpInfo(UserRegistrationRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/registration/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Create user registration session
  ///
  /// 
  Future<UserRegistrationResponse> registrationSessionCreate(UserRegistrationRequest request) async {
    Response response = await registrationSessionCreateWithHttpInfo(request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'UserRegistrationResponse') as UserRegistrationResponse;
    } else {
      return null;
    }
  }

  /// Send email validation message with HTTP info returned
  ///
  /// 
  Future registrationSessionValidateWithHttpInfo(String sessionId) async {
    Object postBody;

    // verify required params are set
    if(sessionId == null) {
     throw ApiException(400, "Missing required param: sessionId");
    }

    // create path and map variables
    String path = "/registration/{sessionId}/validate/".replaceAll("{format}","json").replaceAll("{" + "sessionId" + "}", sessionId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Send email validation message
  ///
  /// 
  Future registrationSessionValidate(String sessionId) async {
    Response response = await registrationSessionValidateWithHttpInfo(sessionId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Verify email address with HTTP info returned
  ///
  /// Verify email address
  Future<Response> registrationSessionVerifyWithHttpInfo(String sessionId, UserRegistrationVerifyRequest verifyRequest) async {
    Object postBody = verifyRequest;

    // verify required params are set
    if(sessionId == null) {
     throw ApiException(400, "Missing required param: sessionId");
    }
    if(verifyRequest == null) {
     throw ApiException(400, "Missing required param: verifyRequest");
    }

    // create path and map variables
    String path = "/registration/{sessionId}/verify/".replaceAll("{format}","json").replaceAll("{" + "sessionId" + "}", sessionId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Verify email address
  ///
  /// Verify email address
  Future<TokenResponse> registrationSessionVerify(String sessionId, UserRegistrationVerifyRequest verifyRequest) async {
    Response response = await registrationSessionVerifyWithHttpInfo(sessionId, verifyRequest);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'TokenResponse') as TokenResponse;
    } else {
      return null;
    }
  }

  /// Sign In with HTTP info returned
  ///
  /// 
  Future<Response> signInWithHttpInfo(SignInRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/signin/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Sign In
  ///
  /// 
  Future<SignInResponse> signIn(SignInRequest request) async {
    Response response = await signInWithHttpInfo(request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'SignInResponse') as SignInResponse;
    } else {
      return null;
    }
  }

  /// Resend OTP for Sign In with HTTP info returned
  ///
  /// 
  Future signInResendWithHttpInfo(String sessionId) async {
    Object postBody;

    // verify required params are set
    if(sessionId == null) {
     throw ApiException(400, "Missing required param: sessionId");
    }

    // create path and map variables
    String path = "/signin/{sessionId}/resend/".replaceAll("{format}","json").replaceAll("{" + "sessionId" + "}", sessionId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Resend OTP for Sign In
  ///
  /// 
  Future signInResend(String sessionId) async {
    Response response = await signInResendWithHttpInfo(sessionId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// One time code verification with HTTP info returned
  ///
  /// 
  Future<Response> signInVerifyWithHttpInfo(String sessionId, SignInVerifyRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(sessionId == null) {
     throw ApiException(400, "Missing required param: sessionId");
    }
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/signin/{sessionId}/verify/".replaceAll("{format}","json").replaceAll("{" + "sessionId" + "}", sessionId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// One time code verification
  ///
  /// 
  Future<TokenResponse> signInVerify(String sessionId, SignInVerifyRequest request) async {
    Response response = await signInVerifyWithHttpInfo(sessionId, request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'TokenResponse') as TokenResponse;
    } else {
      return null;
    }
  }

  /// Sign Up with HTTP info returned
  ///
  /// 
  Future<Response> signUpWithHttpInfo(SignUpRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/signup/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Sign Up
  ///
  /// 
  Future<SignUpResponse> signUp(SignUpRequest request) async {
    Response response = await signUpWithHttpInfo(request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'SignUpResponse') as SignUpResponse;
    } else {
      return null;
    }
  }

  /// Resend OTP for Sign Up with HTTP info returned
  ///
  /// 
  Future signUpResendWithHttpInfo(String sessionId) async {
    Object postBody;

    // verify required params are set
    if(sessionId == null) {
     throw ApiException(400, "Missing required param: sessionId");
    }

    // create path and map variables
    String path = "/signup/{sessionId}/resend/".replaceAll("{format}","json").replaceAll("{" + "sessionId" + "}", sessionId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Resend OTP for Sign Up
  ///
  /// 
  Future signUpResend(String sessionId) async {
    Response response = await signUpResendWithHttpInfo(sessionId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Sign Up verification with HTTP info returned
  ///
  /// 
  Future<Response> signUpVerifyWithHttpInfo(String sessionId, SignUpVerifyRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(sessionId == null) {
     throw ApiException(400, "Missing required param: sessionId");
    }
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/signup/{sessionId}/verify/".replaceAll("{format}","json").replaceAll("{" + "sessionId" + "}", sessionId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Sign Up verification
  ///
  /// 
  Future<TokenResponse> signUpVerify(String sessionId, SignUpVerifyRequest request) async {
    Response response = await signUpVerifyWithHttpInfo(sessionId, request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'TokenResponse') as TokenResponse;
    } else {
      return null;
    }
  }

}
